<template>
  <div class="invoice-header-list-comp">
    <div class="invoice-header-item" v-for="(invoice,i) in props.invoiceHeaderList" :key="i" @click="chooseInvoiceItem(i)">
      <div class="has-invoice" v-if="JSON.stringify(invoice) !== '{}'">
        <div class="title">{{ invoice.title }}</div>
        <div class="invoice-type">发票类型：{{ invoice.fapiaoType === 0 ? '增值税电子普通发票' : '增值税电子专用发票' }}</div>
        <div class="btns">
          <div class="edit-btn" @click.stop="openInvoiceHeaderDialog(invoice, 'edit')">编辑</div>
          <div class="del-btn" @click.stop="delInvoiceHeader(invoice,i)">删除</div>
        </div>
      </div>
      <div class="no-invoice" v-else @click="openInvoiceHeaderDialog">
        <el-icon size="32" color="#909399">
          <Plus />
        </el-icon>
        <span class="add-tip">添加新发票地址</span>
      </div>
    </div>

    <invoiceHeaderDialog :showAddInvoiceHeaderDialog="source.showAddInvoiceHeaderDialog" :type="source.type" :invoiceInfo="source.invoiceInfo" @updateInvoiceHeader="updateInvoiceHeader" @closeAddInvoiceHeaderDialog="closeInvoiceHeaderDialog"/>
  </div>
</template>

<script setup lang="ts">
import { reactive } from 'vue';
import { ElMessageBox } from 'element-plus';
import invoiceHeaderDialog from './invoiceHeaderDialog.vue';

interface Props {
  invoiceHeaderList: Array<any>
}
const props = defineProps<Props>();
const emit = defineEmits(['updateInvoiceHeader', 'delInvoice', 'chooseInvoiceItem']);

const source = reactive({
  showAddInvoiceHeaderDialog: false,
  type: 'add',
  invoiceInfo: {}
});

const chooseInvoiceItem = (index: number):void => {
  emit('chooseInvoiceItem', { index });
}

const openInvoiceHeaderDialog = (invoice?: Record<any,any>, type?:string):void => {
  console.info('type invoice', type, invoice);
  source.type = type as any;
  type === 'edit' ? source.invoiceInfo = invoice as any : null;
  source.showAddInvoiceHeaderDialog = true;
}

const closeInvoiceHeaderDialog = ():void => {
  source.showAddInvoiceHeaderDialog = false;
}

const updateInvoiceHeader = (data: Record<any, any>):void => {
  emit('updateInvoiceHeader', data);
  source.showAddInvoiceHeaderDialog = false;
}

const delInvoiceHeader = (invoice: Record<any, any>, index: number):void => {
  ElMessageBox.confirm('确认要删除吗？', '提示', {
    confirmButtonText: '确定',
    cancelButtonText: '取消'
  }).then(() => {
    emit('delInvoice', { invoice, index });
  }).catch(() => {});
}
</script>

<style lang="scss" scoped>
.invoice-header-list-comp {
  display: flex;
  flex-direction: row;
  flex-wrap: wrap;

  .invoice-header-item {
    width: 285px;
    height: 160px;
    position: relative;
    background: #FFFFFF;
    border: 1px solid #DCDFE6;
    box-sizing: border-box;
    margin-top: 15px;
    margin-right: 30px;

    .has-invoice {
      display: flex;
      flex-direction: column;
      width: 100%;
      height: 100%;

      .title {
        font-family: Microsoft YaHei-Bold, Microsoft YaHei;
        font-weight: 700;
        color: #303133;
        margin-top: 24px;
        margin-left: 25px;
      }

      .invoice-type {
        font-size: 14px;
        font-family: Microsoft YaHei-Regular, Microsoft YaHei;
        color: #303133;
		margin: 12px 0 31px 25px;
      }

      .btns {
        display: flex;
        flex-direction: row;
        justify-content: flex-end;
        align-items: center;
        margin-top: 16px;

        .edit-btn {
          font-size: 12px;
          font-family: Microsoft YaHei-Regular, Microsoft YaHei;
          color: #0F71FF;
          margin-right: 20px;
        }

        .del-btn {
          font-size: 12px;
          font-family: Microsoft YaHei-Regular, Microsoft YaHei;
          color: #0F71FF;
          margin-right: 24px;
        }
      }

      .is-default {
        display: flex;
        flex-direction: column;
        justify-content: center;
        align-items: center;
        width: 60px;
        height: 26px;
        position: absolute;
        top: 0px;
        right: 0px;
        background: #0F71FF;
        font-size: 14px;
        font-family: Microsoft YaHei-Regular, Microsoft YaHei;
        color: #FFFFFF;
      }

      .check-icon {
        width: 32px;
        height: 32px;
        position: absolute;
        bottom: 0px;
        right: 0px;
      }
    }

    .no-invoice {
      display: flex;
      flex-direction: column;
      justify-content: center;
      align-items: center;
      width: 100%;
      height: 100%;

      .add-tip {
        font-size: 14px;
        font-family: Microsoft YaHei-Regular, Microsoft YaHei;
        color: #909399;
        margin-top: 26px;
      }
    }
  }
}
</style>